# Example
## Declare

The [declare.rs](declare.rs) file contains some basic examples to 
help you understand how to use `Tonbo` for simple data operations in your project.

## Datafusion
The [datafusion.rs](datafusion.rs) file demonstrates the in-depth integration of the `Tonbo` project 
with `DataFusion` and shows how to use the powerful features of DataFusion to perform complex data processing tasks.
